import { Button, TableCell, TableRow } from '@mui/material'
import ConfirmDialog from 'components/confirmDialog'
import { Identity } from 'interfaces'
import { useState } from 'react'
import { submitJsonOpts } from 'utils'
import CheckIcon from '@mui/icons-material/Check'
import { useHistory } from 'react-router-dom'

interface IdentityLineProps {
  text: string
  identity: Identity | null
}
const IdentityLine = ({ text, identity }: IdentityLineProps) => {
  // Make a line with a confirmation button if the identity has not been verified
  const [confirmOpen, setConfirmOpen] = useState(false)
  const history = useHistory()
  const verifyIdentity = (id: string) => async () => {
    await fetch(`/api/ui/v1/identity/${id}`, submitJsonOpts('PATCH', {}))
    history.go(0)
  }

  if (identity == null) {
    return <></>
  }
  return (
    <TableRow>
      <TableCell align="left">{text}</TableCell>
      <TableCell align="left">{identity ? identity.value : ''}</TableCell>
      <TableCell>
        {!identity.verified_at ? (
          <div>
            <Button
              aria-label="verify"
              onClick={() => setConfirmOpen(true)}
              disabled={!identity}
            >
              Verify
            </Button>
            <ConfirmDialog
              title="TODO transaltion Confirm?"
              open={confirmOpen}
              setOpen={setConfirmOpen}
              onConfirm={verifyIdentity(identity.id)}
            >
              TODO: translation Are you sure you want to verify this identity?
            </ConfirmDialog>
          </div>
        ) : (
          <CheckIcon sx={{ fill: 'green' }} />
        )}
      </TableCell>
    </TableRow>
  )
}

export default IdentityLine
