import { useEffect, useState } from 'react'
import { FetchedGuest, Guest } from 'interfaces'
import { parseIdentity, parseRole } from 'utils'

const useGuests = () => {
  const [guests, setGuests] = useState<Guest[]>([])

  const getGuestsInfo = async () => {
    try {
      const response = await fetch('/api/ui/v1/guests/?format=json')
      const jsonResponse = await response.json()
      if (response.ok) {
        const persons = await jsonResponse.persons
        setGuests(
          persons.map(
            (person: FetchedGuest): Guest => ({
              pid: person.pid,
              first: person.first,
              last: person.last,
              email: person.email,
              mobile: person.mobile,
              fnr: parseIdentity(person.fnr),
              passport: parseIdentity(person.passport),
              active: person.active,
              roles: person.roles.map((role) => parseRole(role)),
              registered: person.registered,
              verified: person.verified,
            })
          )
        )
      }
    } catch (error) {
      setGuests([])
    }
  }

  const reloadGuests = () => {
    getGuestsInfo()
  }

  useEffect(() => {
    getGuestsInfo()
  }, [])

  return { guests, reloadGuests }
}

export default useGuests
