import React from 'react'
import { render, screen, waitFor } from 'test-utils'
import AdapterDateFns from '@mui/lab/AdapterDateFns'
import { LocalizationProvider } from '@mui/lab'
import GuestRegisterStep from './registerPage'
import { EnteredGuestData } from './enteredGuestData'
import AuthenticationMethod from './authenticationMethod'
import { GuestInviteInformation } from './guestDataForm'

function getEmptyGuestData(): GuestInviteInformation {
  return {
    first_name: '',
    last_name: '',
    ou_name_en: '',
    ou_name_nb: '',
    role_name_en: '',
    role_name_nb: '',
    role_start: '',
    role_end: '',
    comment: '',
    email: '',
    mobile_phone: '',
    fnr: '',
    passport: '',
    countryForCallingCode: '',
    authentication_method: AuthenticationMethod.Invite,
  }
}

test('Guest register page showing passport field on manual registration', async () => {
  const nextHandler = (enteredGuestData: EnteredGuestData) => {
    console.log(`Entered data: ${enteredGuestData}`)
  }

  render(
    <LocalizationProvider dateAdapter={AdapterDateFns}>
      <GuestRegisterStep
        nextHandler={nextHandler}
        guestData={getEmptyGuestData()}
      />
    </LocalizationProvider>
  )

  await waitFor(() => {
    expect(screen.queryByTestId('passport_number_input')).toBeInTheDocument()
  })
})
