import useGuest from 'hooks/useGuest'
import { Route, useParams } from 'react-router-dom'
import { submitJsonOpts } from 'utils'
import GuestInfo from './guestInfo'
import GuestRoleInfo from './guestRoleInfo'
import NewGuestRole from './newGuestRole'

type GuestInfoParams = {
  pid: string
}

type GuestRoutesProps = {
  reloadGuests: () => void
}

function GuestRoutes({ reloadGuests }: GuestRoutesProps) {
  const { pid } = useParams<GuestInfoParams>()
  const { guestInfo, reloadGuestInfo } = useGuest(pid)

  const updateEmail = (validEmail: string) => {
    fetch(
      `/api/ui/v1/person/${pid}`,
      submitJsonOpts('PATCH', { email: validEmail })
    )
      .then((res) => {
        if (res.ok) {
          // Just reload data from the server, it will cause the children
          // to be rerendered
          reloadGuestInfo()
        }
      })
      .catch((error) => {
        console.log('error', error)
      })
  }

  // Resending the invitation does not cause a change in the state, so nothing needs to be updated after the call
  const resend = () => {
    fetch(`/api/ui/v1/invite/${pid}/resend`, submitJsonOpts('PATCH', {}))
      .then((res) => {
        if (!res.ok) {
          return null
        }
        return res.text()
      })
      .then((result) => {
        if (result !== null) {
          console.log('result', result)
        }
      })
      .catch((error) => {
        console.log('error', error)
      })
  }

  return (
    <>
      <Route path="/sponsor/guest/:pid/roles/:id">
        <GuestRoleInfo guest={guestInfo} />
      </Route>
      <Route exact path="/sponsor/guest/:pid/newrole">
        <NewGuestRole guest={guestInfo} reloadGuestInfo={reloadGuestInfo} />
      </Route>
      <Route exact path="/sponsor/guest/:pid">
        <GuestInfo
          guest={guestInfo}
          updateEmail={updateEmail}
          resend={resend}
          reloadGuests={reloadGuests}
        />
      </Route>
    </>
  )
}

export default GuestRoutes
