from django.contrib import admin
from reversion.admin import VersionAdmin

from greg.models import (
    OuIdentifier,
    Invitation,
    InvitationLink,
    Notification,
    Person,
    Role,
    RoleType,
    Identity,
    ConsentType,
    Consent,
    OrganizationalUnit,
    Sponsor,
    SponsorOrganizationalUnit,
)

admin.site.site_header = "Guest Registration Admin"


class RoleInline(admin.TabularInline):
    model = Role
    extra = 1


class IdentityInline(admin.TabularInline):
    model = Identity
    extra = 1


class ConsentInline(admin.TabularInline):
    model = Consent
    extra = 1


class PersonAdmin(VersionAdmin):
    list_display = (
        "first_name",
        "last_name",
        "role_count",
    )
    search_fields = ("first_name", "last_name")  # TODO: "identities__value"?
    readonly_fields = ("id", "created", "updated")
    inlines = (RoleInline, IdentityInline, ConsentInline)

    def role_count(self, person):
        return str(person.roles.count())

    role_count.short_description = "# roles"  # type: ignore


class RoleAdmin(VersionAdmin):
    list_display = ("id", "person", "type")
    search_fields = (
        "person__id",
        "type__id",
    )
    raw_id_fields = ("person", "type")
    readonly_fields = ("id", "created", "updated")


class RoleTypeAdmin(VersionAdmin):
    list_display = ("id", "identifier", "name_nb", "name_en")
    readonly_fields = ("id", "created", "updated")


class IdentityAdmin(VersionAdmin):
    list_display = ("id", "person", "type", "verified")
    list_filter = ("verified",)
    readonly_fields = ("id", "created", "updated")


class ConsentAdmin(VersionAdmin):
    list_display = ("id", "person", "get_consent_type_name")
    readonly_fields = ("id", "created", "updated")

    def get_consent_type_name(self, obj):
        return obj.type.name_en

    get_consent_type_name.short_description = "Consent name"  # type: ignore


class ConsentTypeAdmin(VersionAdmin):
    list_display = (
        "id",
        "name_en",
        "valid_from",
        "user_allowed_to_change",
        "mandatory",
    )
    readonly_fields = ("id", "created", "updated")


class OuIdentifierInline(admin.TabularInline):
    model = OuIdentifier
    extra = 1


class IdentifierAdmin(VersionAdmin):
    list_display = ("id", "name", "source", "value")
    search_fields = ("id", "value")


class OrganizationalUnitAdmin(VersionAdmin):
    list_display = ("id", "name_en", "parent")
    readonly_fields = ("id", "created", "updated")
    search_fields = ("name_en", "id")
    inlines = (OuIdentifierInline,)


class OrganizationalUnitInline(admin.TabularInline):
    model = SponsorOrganizationalUnit
    extra = 1


class SponsorAdmin(VersionAdmin):
    list_display = ("id", "feide_id")
    inlines = (OrganizationalUnitInline,)
    readonly_fields = ("id", "created", "updated")


class SponsorOrganizationalUnitAdmin(VersionAdmin):
    readonly_fields = ("id", "created", "updated")


class InvitationAdmin(VersionAdmin):
    list_display = ("id",)


class InvitationLinkAdmin(VersionAdmin):
    list_display = ("uuid", "invitation", "created", "expire")
    readonly_fields = ("uuid",)


class NotificationAdmin(VersionAdmin):
    list_display = (
        "id",
        "object_type",
        "identifier",
        "operation",
        "created",
        "updated",
        "issued_at",
    )


admin.site.register(Person, PersonAdmin)
admin.site.register(Role, RoleAdmin)
admin.site.register(RoleType, RoleTypeAdmin)
admin.site.register(Identity, IdentityAdmin)
admin.site.register(Consent, ConsentAdmin)
admin.site.register(ConsentType, ConsentTypeAdmin)
admin.site.register(OrganizationalUnit, OrganizationalUnitAdmin)
admin.site.register(Sponsor, SponsorAdmin)
admin.site.register(SponsorOrganizationalUnit, SponsorOrganizationalUnitAdmin)
admin.site.register(Invitation, InvitationAdmin)
admin.site.register(InvitationLink, InvitationLinkAdmin)
admin.site.register(OuIdentifier, IdentifierAdmin)
admin.site.register(Notification, NotificationAdmin)
