from django.core.exceptions import ValidationError
from rest_framework import serializers

from greg.models import Identity


class IdentitySerializer(serializers.ModelSerializer):
    class Meta:
        model = Identity
        fields = "__all__"

    def is_duplicate(self, identity_type: str, value: str) -> bool:
        # Guests may be verified using another unrecognised identification method,
        # which the sponsor is required to elaborate in the value column.
        # In this case we cannot assume the union of the identity type and
        # the value to be unique across all records.
        if identity_type == Identity.IdentityType.OTHER:
            return False

        # If the type is a specific ID type, then duplicates are not expected
        return Identity.objects.filter(type=identity_type).filter(value=value).exists()

    def validate(self, attrs):
        if self.is_duplicate(attrs["type"], attrs["value"]):
            raise ValidationError("Identity already exists")
        return attrs
