import re
import phonenumbers
from rest_framework import serializers

from greg.utils import is_valid_norwegian_national_id_number

_valid_email_regex = r"\b[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Z|a-z]{2,}\b"


def validate_norwegian_national_id_number(value):
    # Not excepted that D-numbers will be entered through the form, so only
    # accept national ID numbers
    if not is_valid_norwegian_national_id_number(value, False):
        raise serializers.ValidationError("Not a valid Norwegian national ID number")


def validate_phone_number(value):
    if not phonenumbers.is_valid_number(phonenumbers.parse(value)):
        raise serializers.ValidationError("Invalid phone number")


def validate_email(value):
    if not re.fullmatch(_valid_email_regex, value):
        raise serializers.ValidationError("Invalid e-mail")
